==> nocc-1.8.1.tbz: www/nocc/lang/be-tarask.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: be-tarask.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Belarusian (Taraškievica orthography) (Беларуская (тарашкевіца))
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author EugeneZelenko
 * @author Jim-by
 */

$lang_locale = 'be-tarask_BY.UTF-8';
$default_date_format = '%d %m %Y';
$no_locale_date_format = '%d %m %Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Імя ўдзельніка не ўведзенае';
$err_passwd_empty = 'Пароль не ўведзены';
$alt_delete = 'Выдаліць выбраныя паведамленьні';
$alt_delete_one = 'Выдаліць паведамленьне';
$alt_new_msg = 'Новыя паведамленьні';
$alt_reply = 'Адказаць аўтару';
$alt_reply_all = 'Адказаць усім';
$alt_forward = 'Пераслаць';
$alt_next = 'Наступнае';
$alt_prev = 'Папярэдняе';
$title_next_page = 'Наступная старонка';
$title_prev_page = 'Папярэдняя старонка';
$title_next_msg = 'Наступнае паведамленьне';
$title_prev_msg = 'Папярэдняе паведамленьне';
$html_on = 'Уключана';
$html_theme_label = 'Афармленьне:';
$html_welcome = 'Запрашаем у %1$s';
$html_login = 'Імя карыстальніка';
$html_passwd = 'Пароль';
$html_submit = 'Увайсьці';
$html_help = 'Дапамога';
$html_server = 'Сэрвэр';
$html_wrong = 'Імя карыстальніка альбо пароль ня слушны';
$html_retry = 'Паспрабаваць ізноў';
$html_remember = 'Запомніць настройкі';
$html_lang_label = 'Мова:';
$html_msgperpage_label = 'Паведамленьняў на старонцы:';
$html_preferences = 'Устаноўкі';
$html_full_name_label = 'Поўнае імя:';
$html_email_address_label = 'Адрас электроннай пошты:';
$html_ccself = 'Копію сабе';
$html_hide_addresses = 'Схаваць адрасы';
$html_outlook_quoting = 'Цытаваньне ў стылі Outlook';
$html_reply_to = 'Адказаць';
$html_use_signature = 'Выкарыстоўваць подпіс';
$html_signature = 'Подпіс';
$html_signature_label = 'Подпіс:';
$html_reply_leadin_label = 'Загаловак адказу:';
$html_prefs_updated = 'Настройкі захаваныя';
$html_manage_folders_link = 'Кіраваньне папкамі IMAP';
$html_manage_filters_link = 'Кіраваньне паштовымі фільтрамі';
$html_use_graphical_smilies = 'Выкарыстоўваць графічнымі ўсьмешкамі';
$html_sent_folder_label = 'Капіяваць дасланыя лісты у адмысловую папку:';
$html_trash_folder_label = 'Пераносіць выдаленыя лісты у адмысловую папку:';
$html_colored_quotes = 'Каляровыя цытаты';
$html_display_struct = 'Паказваць структураваны тэкст';
$html_send_html_mail = 'Даслаць ліст у фармаце HTML';
$html_folders = 'Папкі';
$html_folders_create_failed = 'Немагчыма стварыць папку!';
$html_folders_sub_failed = 'Немагчыма далучыць папку!';
$html_folders_unsub_failed = 'Немагчыма адлучыць папку!';
$html_folders_rename_failed = 'Немагчыма перайменаваць папку!';
$html_folders_updated = 'Папкі абноўлены';
$html_folder_subscribe = 'Падпісацца на';
$html_folder_rename = 'Перайменаваць';
$html_folder_create = 'Стварыць новую папку';
$html_folder_remove = 'Адпісацца ад';
$html_folder_delete = 'Выдаліць';
$html_folder_to = 'да';
$html_filter_remove = 'Выдаліць';
$html_filter_body = 'Тэкст паведамленьня';
$html_filter_subject = 'Тэма паведамленьня';
$html_filter_to = 'Поле Каму';
$html_filter_cc = 'Поле Копія';
$html_filter_from = 'Поле Ад';
$html_filter_change_tip = 'Каб зьмяніць фільтар, проста яго перазапішыце.';
$html_reapply_filters = 'Ужыць усе фільтры ізноў';
$html_filter_contains = 'зьмяшчае';
$html_filter_name = 'Назва фільтру';
$html_filter_action = 'Дзеяньне фільтру';
$html_filter_moveto = 'Перанесьці ў';
$html_select_one = '--Выбраць адно--';
$html_and = 'і';
$html_new_msg_in = 'Новыя паведамленьні ў';
$html_or = 'ці';
$html_move = 'Перанесьці';
$html_copy = 'Скапіяваць';
$html_messages_to = 'выбраныя паведамленьні да';
$html_gotopage = 'Перайсьці на старонку';
$html_gotofolder = 'Перайсьці ў папку';
$html_other_folders = 'Сьпіс папак';
$html_page = 'Старонка';
$html_of = 'з';
$html_view_header = 'Паказаць загаловак';
$html_remove_header = 'Схаваць загаловак';
$html_inbox = 'Уваходзячыя';
$html_new_msg = 'Напісаць';
$html_reply = 'Адказаць';
$html_reply_short = 'Адк.';
$html_reply_all = 'Адказаць усім';
$html_forward = 'Пераслаць';
$html_forward_short = 'Пер.';
$html_forward_info = 'Паведамленьне, якое перасылаецца, будзе дасланае як далучэньне да гэтага.';
$html_delete = 'Выдаліць';
$html_new = 'Новае';
$html_mark = 'Выдаліць';
$html_att_label = 'Далучэньне:';
$html_atts_label = 'Далучэньні';
$html_att_unknown = '[невядомы]';
$html_attach = 'Далучыць';
$html_attach_forget = 'Вы павінны далучыць Ваш файл перад дасылкай Вашага паведамленьня!';
$html_attach_delete = 'Выдаліць выбраныя';
$html_attach_none = 'Вам неабходна выбраць файл для далучэньня!';
$html_sort_by = 'Сартаваць па';
$html_sort = 'Сартаваць';
$html_from = 'Ад';
$html_from_label = 'Ад:';
$html_subject = 'Тэма';
$html_subject_label = 'Тэма:';
$html_date = 'Дата';
$html_date_label = 'Дата:';
$html_sent = 'Даслаць:';
$html_wrote = 'напісаў(ла)';
$html_size = 'Памер';
$html_totalsize = 'Агульны памер';
$html_kb = 'кб';
$html_mb = 'Мб';
$html_gb = 'Гб';
$html_bytes = 'байт';
$html_filename = 'Назва файла';
$html_to = 'Да';
$html_to_label = 'Да:';
$html_cc = 'Копія';
$html_cc_label = 'Копія:';
$html_bcc_label = 'Схаваная копія:';
$html_nosubject = 'Няма тэмы';
$html_send = 'Даслаць';
$html_cancel = 'Адмяніць';
$html_no_mail = 'Паведамленьняў няма.';
$html_logout = 'Выйсьці';
$html_msg = 'Паведамленьне';
$html_msgs = 'Паведамленьні';
$html_configuration = 'Гэты сэрвэр усталяваны няслушна!';
$html_priority = 'Прыярытэт';
$html_priority_label = 'Прыярытэт:';
$html_lowest = 'Самы нізкі';
$html_low = 'Нізкі';
$html_normal = 'Звычайны';
$html_high = 'Высокі';
$html_highest = 'Самы высокі';
$html_receipt = 'Запытаць пацьверджаньне атрыманьня паведамленьня';
$html_select = 'Выбраць';
$html_select_all = 'Інвэртаваць выбар';
$html_loading_image = 'Загрузка выявы';
$html_send_confirmed = 'Ваша паведамленьне было прынятае да адпраўкі';
$html_no_sendaction = 'Дзеяньне не пазначанае. Паспрабуйце ўключыць JavaScript.';
$html_error_occurred = 'Адбылася памылка';
$html_prefs_file_error = 'Немагчыма адкрыць файл установак для запісу.';
$html_wrap = 'Колькасьць сымбаляў, якая выклікае перанос на новы радок у дасылаемых паведамленьнях:';
$html_wrap_none = 'Без пераносу на новы радок';
$html_usenet_separator = 'Падзяляльнік у стылі Usenet ("-- \n") перад подпісам';
$html_mark_as = 'Пазначыць як';
$html_read = 'прачытанае';
$html_unread = 'непрачытанае';
$html_encoding_label = 'Кадыроўка сымбаляў:';
$html_add = 'Дадаць';
$html_contacts = 'Кантакты %1$s';
$html_modify = 'Зьмяніць';
$html_back = 'Назад';
$html_contact_add = 'Дадаць новы кантакт';
$html_contact_mod = 'Зьмяніць кантакт';
$html_contact_first = 'Імя';
$html_contact_last = 'Прозьвішча';
$html_contact_nick = 'Мянушка';
$html_contact_mail = 'Адрас электроннай пошты';
$html_contact_list = 'Сьпіс кантактаў %1$s';
$html_contact_del = 'са сьпісу кантактаў';
$html_contact_count = '%1$d кантактаў';
$html_contact_err1 = 'Максымальная колькасьць кантактаў — «%1$d»';
$html_contact_err2 = 'Вы ня можаце дадаць новы кантакт';
$html_contact_err3 = 'Вы ня маеце правоў доступу да сьпісу кантактаў';
$html_contact_none = 'Немагчыма знайсьці кантакты.';
$html_del_msg = 'Выдаліць выбраныя паведамленьні?';
$html_down_mail = 'Загрузіць';
$original_msg = '-- Арыгінальнае паведамленьне --';
$to_empty = 'Поле \'Каму\' ня можа быць пустым!';
$html_images_warning = 'Для Вашай бясьпекі, вонкавыя выявы не паказваюцца.';
$html_images_display = 'Паказваць выявы';
$html_smtp_error_no_conn = 'Немагчыма стварыць SMTP-злучэньне';
$html_smtp_error_unexpected = 'Нечаканы SMTP-адказ:';
$lang_could_not_connect = 'Немагчыма далучыцца да сэрвэра';
$lang_invalid_msg_num = 'Няслушны нумар паведамленьня';
$html_file_upload_attack = 'Верагодная атака праз загрузку файла';
$html_invalid_email_address = 'Няслушны адрас электроннай пошты';
$html_invalid_msg_per_page = 'Няслушная колькасьць паведамленьняў на старонцы';
$html_invalid_wrap_msg = 'Няслушная шырыня радку ў паведамленьні';
$html_seperate_msg_win = 'Паведамленьне ў асобным акне';
$html_err_file_contacts = 'Немагчыма адкрыць файл кантактаў для запісу.';
$html_session_file_error = 'Немагчыма адчыніць файл сэсіі для запісу.';
$html_login_not_allowed = 'Гэтаму удзельніку далучэньне не дазволена.';
$lang_err_send_delay = 'Вам неабходна пачакаць паміж дасылкай двух электронных лістоў (%1$d сэкундаў)';
$html_search = 'Пошук';

==> nocc-1.8.3.tbz: www/nocc/lang/be-tarask.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: be-tarask.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Belarusian (Taraškievica orthography) (Беларуская (тарашкевіца))
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author EugeneZelenko
 * @author Jim-by
 * @author Wizardist
 */

$lang_locale = 'be-tarask_BY.UTF-8';
$default_date_format = '%d %m %Y';
$no_locale_date_format = '%d %m %Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Імя ўдзельніка не ўведзенае';
$err_passwd_empty = 'Пароль не ўведзены';
$alt_delete = 'Выдаліць выбраныя паведамленьні';
$alt_delete_one = 'Выдаліць паведамленьне';
$alt_new_msg = 'Новыя паведамленьні';
$alt_reply = 'Адказаць аўтару';
$alt_reply_all = 'Адказаць усім';
$alt_forward = 'Пераслаць';
$alt_next = 'Наступнае';
$alt_prev = 'Папярэдняе';
$title_next_page = 'Наступная старонка';
$title_prev_page = 'Папярэдняя старонка';
$title_next_msg = 'Наступнае паведамленьне';
$title_prev_msg = 'Папярэдняе паведамленьне';
$html_theme_label = 'Афармленьне:';
$html_welcome = 'Запрашаем у %1$s';
$html_login = 'Увайсьці';
$html_user_label = 'Карыстальнік:';
$html_passwd_label = 'Пароль:';
$html_submit = 'Увайсьці';
$html_help = 'Дапамога';
$html_server_label = 'Сэрвэр:';
$html_wrong = 'Імя карыстальніка альбо пароль ня слушны';
$html_retry = 'Паспрабаваць ізноў';
$html_remember = 'Запомніць настройкі';
$html_lang_label = 'Мова:';
$html_msgperpage_label = 'Паведамленьняў на старонцы:';
$html_preferences = 'Устаноўкі';
$html_full_name_label = 'Поўнае імя:';
$html_email_address_label = 'Адрас электроннай пошты:';
$html_ccself = 'Копію сабе';
$html_hide_addresses = 'Схаваць адрасы';
$html_outlook_quoting = 'Цытаваньне ў стылі Outlook';
$html_reply_to = 'Адказаць';
$html_use_signature = 'Выкарыстоўваць подпіс';
$html_signature = 'Подпіс';
$html_signature_label = 'Подпіс:';
$html_reply_leadin_label = 'Загаловак адказу:';
$html_prefs_updated = 'Настройкі захаваныя';
$html_manage_folders_link = 'Кіраваньне папкамі IMAP';
$html_manage_filters_link = 'Кіраваньне паштовымі фільтрамі';
$html_use_graphical_smilies = 'Выкарыстоўваць графічнымі ўсьмешкамі';
$html_sent_folder_label = 'Капіяваць дасланыя лісты у адмысловую папку:';
$html_trash_folder_label = 'Пераносіць выдаленыя лісты у адмысловую папку:';
$html_colored_quotes = 'Каляровыя цытаты';
$html_display_struct = 'Паказваць структураваны тэкст';
$html_send_html_mail = 'Даслаць ліст у фармаце HTML';
$html_folders = 'Папкі';
$html_folders_create_failed = 'Немагчыма стварыць папку!';
$html_folders_sub_failed = 'Немагчыма далучыць папку!';
$html_folders_unsub_failed = 'Немагчыма адлучыць папку!';
$html_folders_rename_failed = 'Немагчыма перайменаваць папку!';
$html_folders_updated = 'Папкі абноўлены';
$html_folder_subscribe = 'Падпісацца на';
$html_folder_rename = 'Перайменаваць';
$html_folder_create = 'Стварыць новую папку';
$html_folder_remove = 'Адпісацца ад';
$html_folder_delete = 'Выдаліць';
$html_folder_to = 'да';
$html_filter_remove = 'Выдаліць';
$html_filter_body = 'Тэкст паведамленьня';
$html_filter_subject = 'Тэма паведамленьня';
$html_filter_to = 'Поле Каму';
$html_filter_cc = 'Поле Копія';
$html_filter_from = 'Поле Ад';
$html_filter_change_tip = 'Каб зьмяніць фільтар, проста яго перазапішыце.';
$html_reapply_filters = 'Ужыць усе фільтры ізноў';
$html_filter_contains = 'зьмяшчае';
$html_filter_name = 'Назва фільтру';
$html_filter_action = 'Дзеяньне фільтру';
$html_filter_moveto = 'Перанесьці ў';
$html_select_one = '--Выбраць адно--';
$html_and = 'і';
$html_new_msg_in = 'Новыя паведамленьні ў';
$html_or = 'ці';
$html_move = 'Перанесьці';
$html_copy = 'Скапіяваць';
$html_messages_to = 'выбраныя паведамленьні да';
$html_gotopage = 'Перайсьці на старонку';
$html_gotofolder = 'Перайсьці ў папку';
$html_other_folders = 'Сьпіс папак';
$html_page = 'Старонка';
$html_of = 'з';
$html_view_header = 'Паказаць загаловак';
$html_remove_header = 'Схаваць загаловак';
$html_inbox = 'Уваходзячыя';
$html_new_msg = 'Напісаць';
$html_reply = 'Адказаць';
$html_reply_short = 'Адк.';
$html_reply_all = 'Адказаць усім';
$html_forward = 'Пераслаць';
$html_forward_short = 'Пер.';
$html_forward_info = 'Паведамленьне, якое перасылаецца, будзе дасланае як далучэньне да гэтага.';
$html_delete = 'Выдаліць';
$html_new = 'Новае';
$html_mark = 'Выдаліць';
$html_att_label = 'Далучэньне:';
$html_atts_label = 'Далучэньні:';
$html_unknown = '[невядомы]';
$html_attach = 'Далучыць';
$html_attach_forget = 'Вы павінны далучыць Ваш файл перад дасылкай Вашага паведамленьня!';
$html_attach_delete = 'Выдаліць выбраныя';
$html_attach_none = 'Вам неабходна выбраць файл для далучэньня!';
$html_sort_by = 'Сартаваць па';
$html_sort = 'Сартаваць';
$html_from = 'Ад';
$html_from_label = 'Ад:';
$html_subject = 'Тэма';
$html_subject_label = 'Тэма:';
$html_date = 'Дата';
$html_date_label = 'Дата:';
$html_sent_label = 'Даслаць:';
$html_wrote = 'напісаў(ла)';
$html_size = 'Памер';
$html_totalsize = 'Агульны памер';
$html_kb = 'кб';
$html_mb = 'Мб';
$html_gb = 'Гб';
$html_bytes = 'байт';
$html_filename = 'Назва файла';
$html_to = 'Да';
$html_to_label = 'Да:';
$html_cc = 'Копія';
$html_cc_label = 'Копія:';
$html_bcc_label = 'Схаваная копія:';
$html_nosubject = 'Няма тэмы';
$html_send = 'Даслаць';
$html_cancel = 'Адмяніць';
$html_no_mail = 'Паведамленьняў няма.';
$html_logout = 'Выйсьці';
$html_msg = 'Паведамленьне';
$html_msgs = 'Паведамленьні';
$html_configuration = 'Гэты сэрвэр усталяваны няслушна!';
$html_priority = 'Прыярытэт';
$html_priority_label = 'Прыярытэт:';
$html_lowest = 'Самы нізкі';
$html_low = 'Нізкі';
$html_normal = 'Звычайны';
$html_high = 'Высокі';
$html_highest = 'Самы высокі';
$html_flagged = 'Пазначаныя';
$html_spam = 'Спам';
$html_spam_warning = 'Гэтае паведамленьне было пазначанае як спам.';
$html_receipt = 'Запытаць пацьверджаньне атрыманьня паведамленьня';
$html_select = 'Выбраць';
$html_select_all = 'Інвэртаваць выбар';
$html_select_contacts = 'Выбраць кантакты';
$html_loading_image = 'Загрузка выявы';
$html_send_confirmed = 'Ваша паведамленьне было прынятае да адпраўкі';
$html_no_sendaction = 'Дзеяньне не пазначанае. Паспрабуйце ўключыць JavaScript.';
$html_error_occurred = 'Адбылася памылка';
$html_prefs_file_error = 'Немагчыма адкрыць файл установак для запісу.';
$html_wrap = 'Колькасьць сымбаляў, якая выклікае перанос на новы радок у дасылаемых паведамленьнях:';
$html_wrap_none = 'Без пераносу на новы радок';
$html_usenet_separator = 'Падзяляльнік у стылі Usenet ("-- \n") перад подпісам';
$html_mark_as = 'Пазначыць як';
$html_read = 'прачытанае';
$html_unread = 'непрачытанае';
$html_encoding_label = 'Кадыроўка сымбаляў:';
$html_add = 'Дадаць';
$html_contacts = 'Кантакты %1$s';
$html_modify = 'Зьмяніць';
$html_back = 'Назад';
$html_contact_add = 'Дадаць новы кантакт';
$html_contact_mod = 'Зьмяніць кантакт';
$html_contact_first = 'Імя';
$html_contact_last = 'Прозьвішча';
$html_contact_nick = 'Мянушка';
$html_contact_mail = 'Адрас электроннай пошты';
$html_contact_list = 'Сьпіс кантактаў %1$s';
$html_contact_del = 'са сьпісу кантактаў';
$html_contact_count = '%1$d кантактаў';
$html_contact_err1 = 'Максымальная колькасьць кантактаў — «%1$d»';
$html_contact_err2 = 'Вы ня можаце дадаць новы кантакт';
$html_contact_err3 = 'Вы ня маеце правоў доступу да сьпісу кантактаў';
$html_contact_none = 'Немагчыма знайсьці кантакты.';
$html_del_msg = 'Выдаліць выбраныя паведамленьні?';
$html_down_mail = 'Загрузіць';
$original_msg = '-- Арыгінальнае паведамленьне --';
$to_empty = 'Поле \'Каму\' ня можа быць пустым!';
$html_images_warning = 'Для Вашай бясьпекі, вонкавыя выявы не паказваюцца.';
$html_images_display = 'Паказваць выявы';
$html_smtp_error_no_conn = 'Немагчыма стварыць SMTP-злучэньне';
$html_smtp_error_unexpected = 'Нечаканы SMTP-адказ:';
$lang_could_not_connect = 'Немагчыма далучыцца да сэрвэра';
$lang_invalid_msg_num = 'Няслушны нумар паведамленьня';
$html_file_upload_attack = 'Верагодная атака праз загрузку файла';
$html_invalid_email_address = 'Няслушны адрас электроннай пошты';
$html_invalid_msg_per_page = 'Няслушная колькасьць паведамленьняў на старонцы';
$html_invalid_wrap_msg = 'Няслушная шырыня радку ў паведамленьні';
$html_seperate_msg_win = 'Паведамленьне ў асобным акне';
$html_err_file_contacts = 'Немагчыма адкрыць файл кантактаў для запісу.';
$html_session_file_error = 'Немагчыма адчыніць файл сэсіі для запісу.';
$html_login_not_allowed = 'Гэтаму удзельніку далучэньне не дазволена.';
$lang_err_send_delay = 'Вам неабходна пачакаць паміж дасылкай двух электронных лістоў (%1$d сэкундаў)';
$html_search = 'Пошук';
